<?php /** @noinspection DuplicatedCode */

use Inc\Claz\Biller;
use Inc\Claz\Customer;
use Inc\Claz\PdoDbException;
use Inc\Claz\Product;
use Inc\Claz\Util;

/*
 *  Script: manage.php
 *      Customers manage page
 *
 *  Last modified:
 *      2018-12-10 by Richard Rowley
 *
 *  License:
 *      GPL v3 or above
 *
 *  Website:
 *      https://simpleinvoices.group
 */
global $LANG, $smarty;

//stop the direct browsing to this file - let index.php handle which files get displayed
Util::directAccessAllowed();

/**
 * Minimize the amount of data returned to the manage table.
 * @return array Data for the manage table rows.
 */
function manageTableInfo(): array
{
    global $config, $LANG, $pdoDb;

    session_name("SiAuth");
    session_start();

    $customerSession = $_SESSION['role_name'] == 'customer';

    $viewCust = $LANG['view'] . " " . $LANG['customerUc'];
    $editCust = $LANG['edit'] . " " . $LANG['customerUc'];
    $defaultInv = $LANG['newUc'] . " " . $LANG['defaultInvoice'];

    try {
        $pdoDb->setOrderBy([['enabled', 'D'], ['name', 'A']]);
    } catch (PdoDbException $pde) {
        error_log("Customer::manageTableInfo(): Unable to set OrderBy - " . $pde->getMessage());
    }

    $rows = Customer::getAll(['order_by_set' => true]);

    $tableRows = [];
    foreach ($rows as $row) {
        $enabled = $row['enabled'] == ENABLED;
        // @formatter:off
        $action = "<a class='index_table' title='{$viewCust} {$row['name']}' " .
            "href='index.php?module=customers&amp;view=view&amp;id={$row['id']}'>" .
            "<img src='images/view.png' class='action' alt='{$viewCust}' />" .
            "</a>" .
            "<a class='index_table' title='{$editCust} {$row['name']}' " .
            "href='index.php?module=customers&amp;view=edit&amp;id={$row['id']}'>" .
            "<img src='images/edit.png' class='action' alt='{$editCust}' />" .
            "</a>";
        if ($enabled && !$customerSession) {
            $action .= "<a class='index_table' title='{$defaultInv}' " .
                "href='index.php?module=invoices&amp;view=usedefault&amp;customer_id={$row['id']}&amp;action=view'>" .
                "<img src='images/add.png' class='action' alt='add' />" .
                "</a>";
        }

        $quickView = "<a class='index_table' title='quick view' " .
            "href='index.php?module=invoices&amp;view=quick_view&amp;id={$row['last_inv_id']}'>" .
            "{$row['last_index_id']}" .
            "</a>";

        $image = $enabled ? "images/tick.png" : "images/cross.png";
        $enabledCol = "<span style='display: none'>{$row['enabled_text']}</span>" .
            "<img src='{$image}' alt='{$row['enabled_text']}' title='{$row['enabled_text']}' />";
        // @formatter::on

        $pattern = '/^(.*)_(.*)$/';
        $replPattern = '$1-$2';
        $tableRows[] = [
            'action' => $action,
            'name' => $row['name'],
            'phone' => empty($row['mobile_phone'])? $row['phone'] : $row['mobile_phone'],
            'quick_view' => $quickView,
            'total' => $row['total'],
            'paid' => $row['paid'],
            'owing' => $row['owing'],
            'enabled' => $enabledCol,
            'currencyCode' => $config['localCurrencyCode'],
            'locale' => preg_replace($pattern, $replPattern, $config['localLocale'])
        ];
    }

    return $tableRows;
}

/**********************************************************************
 * These settings are used to force user to enter the first biller,
 * customer and product when a new installation with empty database
 * has been performed.
 * TODO: Need better way to determine if still in initialization phase.
 */
$customers = manageTableInfo();
$customerCount = count($customers);
$billerCount = Biller::count();
$productCount  = Product::count();

$smarty->assign('number_of_billers'  , $billerCount);
$smarty->assign('number_of_customers', $customerCount);
$smarty->assign('number_of_products' , $productCount);

$firstRunWizard = $billerCount == 0 || $customerCount == 0 || $productCount == 0;
$smarty->assign("first_run_wizard",$firstRunWizard);
/**********************************************************************/

// No need to do all this if first_run_wizard specified
if (!$firstRunWizard) {
    $data = json_encode(['data' => $customers]);
    if (file_put_contents("public/data.json", $data) === false) {
        die("Unable to create public/data.json file");
    }

    $smarty->assign('numberOfRows', $customerCount);
}

$smarty->assign('pageActive', 'customer');
$smarty->assign('activeTab', '#people');
